@@ -1,4 +1,4 @@
 # As I import the .py module from inside a package
 # that's why I need to use '.plt_rdf'
 # '.' means this path
-from .plt_rdf import rdf
+from .plot_rdf import rdf
