@@ -1,6 +1,4 @@
-# This class calculates RDF using freud
-
-from freud import density, box
+from freud import density
 
 class RDF:
     def __init__(self, bins, r_max, box, positions):
@@ -11,9 +9,7 @@ class RDF:
 
     def calc_RDF(self):
         RDF = density.RDF(self.bins, self.r_max)
-        box_arr = box.Box(Lx=self.box[0], Ly=self.box[1], Lz=self.box[2],
-                                                    xy=self.box[3], xz=self.box[4], yz=self.box[5], is2D=False)
-
+        box_arr = self.box
         RDF.compute(system=(box_arr, self.positions), reset=False)
 
-        return RDF.bin_centers, RDF.rdf
+        return RDF.bin_centers, RDF.rdf
\ No newline at end of file
